@@ -5,8 +5,8 @@
 ;; Author: Yoshinari Nomura <nom@quickhack.net>
 ;; Maintainer: Yoshinari Nomura <nom@quickhack.net>
 ;; Created: December 2025
-;; Package-Version: 20260112.423
-;; Package-Revision: 99e5e0f387de
+;; Package-Version: 20260202.1350
+;; Package-Revision: afaf52a34050
 ;; Keywords: OpenSCAD languages tree-sitter
 ;; URL: https://github.com/yoshinari-nomura/scad-ts-mode
 ;; Package-Requires: ((emacs "29.3"))
@@ -285,20 +285,34 @@ See `regexp-opt' for details."
      ((parent-is "block") standalone-parent scad-ts-indent-offset)
      ((parent-is "transform_chain") parent-bol scad-ts-indent-offset)
 
-     ;; Second or later arguments/list-values follow the first sibling
+     ;;    function name() =
+     ;; <TAB>1;
+     ((parent-is "function_item") parent-bol scad-ts-indent-offset)
+     ;;    module name()
+     ;; <TAB>cube(5);
+     ((parent-is "module_item") parent-bol scad-ts-indent-offset)
+
+     ;; Second or later call arguments/declaration prams/list-values
+     ;; follow the first sibling
      ((match nil "arguments" nil 2 nil) (nth-sibling 1) 0)
      ((match nil "parameters" nil 2 nil) (nth-sibling 1) 0)
      ((match nil "list" nil 2 nil) (nth-sibling 1) 0)
-     ;; let(a=1, b=1...
+     ;;  let (a=1,
+     ;; <TAB> b=1
      ((match nil "assignments" nil 2 nil) (nth-sibling 1) 0)
 
      ;; First argument/list-value should be indented
      ((parent-is "arguments") parent-bol scad-ts-indent-offset)
      ((parent-is "parameters")  (nth-sibling 0) 1)
      ((parent-is "list") parent-bol scad-ts-indent-offset)
-     ;; let(a=1, b=1...
+     ;;    let (
+     ;; <TAB>a=1
      ((parent-is "assignments") parent-bol scad-ts-indent-offset)
 
+     ;;    variable =
+     ;; <TAB>1;
+     ((parent-is "assignment") parent-bol scad-ts-indent-offset)
+
      ;; If the node is inside an Error, the most likely situation is
      ;; that you pressed TAB while an if-statement or array-block is
      ;; still open (in the middle of input):
